@@ -52,7 +52,7 @@ using namespace ZenLib;
 #define QString2wstring(_DATA) \
     Ztring().From_UTF8(_DATA.toUtf8())
 
-#define VERSION "25.10.20260118"
+#define VERSION "25.10.20260125"
 
 #ifndef MEDIAINFO_HTML_NO
 #include "htmlwidget.h"
@@ -514,6 +514,10 @@ void MainWindow::updateProgressBar ()
         progressDialog->hide();
         timer->stop();
 
+        //Cancel MediaInfoLib parsing if canceled
+        if (progressDialog->wasCanceled())
+            C->Menu_File_Open_Files_Begin(true);
+
         delete progressDialog; progressDialog=NULL;
         delete timer; timer=NULL;
 
